@@ -93,7 +93,7 @@
 #include "cwdaemon.h"
 
 /* network vars */
-int sin_len, reply_socklen;
+socklen_t sin_len, reply_socklen;
 int socket_descriptor;
 struct sockaddr_in k_sin, reply_sin;
 int port = 6789;		/* default UDP port we listen on */
